/********************************************************************
 *  Copyright (C) 1999-2004 by  ZiLOG, Inc.
 *  All Rights Reserved
 ********************************************************************/

/*********************************************************************
 *   Zilog LedBlink sample was design to demonstrates the following 
 *   functionality on the standard development boards:
 *   - Setting up status routine to monitor events
 *   - Setting up a timer to toggle the leds
 *   - Setting up a Uart to transmit led colors and receive input 
 *     a keyboard event to toggle the direction of the leds
 *   - Setting up an event on a port to toggle the direction of the 
 *     leds
 * 
 *  Required terminal setup to communicate with the Sample:
 *      57600 bps, 8 bits per character, No parity, 1 stop bit, No flow ctrl
 *
 *
 * NOTE:  Including UART specific statements while the UART is disabled will
 *        prevent the program from operating as intended.
 *        
 *        We recommend that you remove the printf()statements from this 
 *        program if you disable the evaluation board's UART.
 *
 *****************************************************************************/

#include <eZ8.h>
#include <stdio.h>
#include <sio.h> // non-standard I/O
#include "main.h"
#include "timer.h"
#include "test_button.h"
#include "uart.h"

// Default user flash optionbits.
FLASH_OPTION1 = 0xFF;
FLASH_OPTION2 = 0xFF;

///////////////////////////////////////////////////////
// Global - Variable
int ProgStat = BUSY;     		// Program status
int ProgDir  = UP;
int button_push = 0;			// 0-1 Wait State 2 > Change State

////////////////////////////////////////////////////////
// A Simple status routine that gets called by the ISR to
// Change status 
void setStatus( int status )
{
	 ProgStat = status; 		//Program status
}

////////////////////////////////////////////////////////
// A Simple routine that toggles the direction of
// leds 
void toggle_uart( void )
{
	 getch();
	 button_push = 2; 		//Program status
}

////////////////////////////////////////////////////////
// A Simple routine that toggles the direction of
// leds 
void toggle_port( void )
{
	button_push = button_push+1;
}

////////////////////////////////////////////////////////
// Main program beings here 
// This  program blinks LED-3 on the evaluation board 
main ()
{	
    int ledstate = 1;
	init_led_gpio();				// Initializes LED ports (Port A)
    init_test_button_gpio();        // Initialize Test Button (Port C)
	DI();							// Disable Interrupts
 	init_timer0();					// Intialize Timer-0
	init_uart0();                   // Intialize Uart
    init_test_button();       		// Initialize Test Button
	EI();							// Enable Interrupts

	while(1)						// Infinte while loop
	{
		if(ProgStat != BUSY)        // Wait for Timer Interrupt
    	{
			if(button_push >= 2) 	// Change direction if Button pushed
			{
			    button_push = 0;
				if(ProgDir == UP)
					ProgDir = DOWN;
				else
					ProgDir = UP;
			}

			switch(ledstate)
      		{
       		 case 1:      
				turn_off_led();		// Turns off ALL LED's
				printf("Led Lights Off\n"); // Write to uart0
                break;
			 case 2:				
				turn_off_led();		// Turns off ALL LED's
				PAOUT &= 0xFE;		// Turn On LED Red
				printf("Led Lights Red\n"); // Write to uart0
				break;
			 case 3:
				turn_off_led();		// Turns off ALL LED's
				PAOUT &= 0xFD;		// Turn On LED Yellow
				printf("Led Lights Yellow\n"); // Write to uart0
				break;
			 case 4:				
				turn_off_led();		// Turns off ALL LED's
				PAOUT &= 0xFB;		// Turn On LED Green
				printf("Led Lights Green\n"); // Write to uart0
				break;

			}
			ProgStat = BUSY;		// Change to wait state
			ProgDir &= 0x01;
			if(ProgDir == UP)
			{
				ledstate++;			// Shift Led
			    if(ledstate == 5 )
				    ledstate = 1;	
			}
			else
			{
				ledstate--;			// Shift Led
			    if(ledstate == 0 )
				    ledstate = 4;	

			}
		}
		
	}

}	// End of main program
